@@ -73,6 +73,17 @@ class ConsoleLogger(object):
             self.oStream.flush()
         return
 
+    def space(self):
+        if self.logStack:
+            padding = []
+            for levelLogger in self.logStack:
+                padding.append(levelLogger.getIntermediatePadding())
+            padding = u''.join(padding)
+        else:
+            padding = u''
+        print >> self.oStream, padding
+        return
+
     def finish(self, message="Done"):
         """
         Ends a hierarchical logging section which was previously created using
